@@ -6,9 +6,10 @@ use File::Spec ();
 use IO::File ();
 use MIME::Types ();
 use MooseX::Types::Moose qw/ArrayRef Str/;
+use Catalyst::Utils;
 use namespace::autoclean;
 
-our $VERSION = '0.29';
+our $VERSION = '0.31';
 
 has _static_file => ( is => 'rw' );
 has _static_debug_message => ( is => 'rw', isa => ArrayRef[Str] );
@@ -16,7 +17,7 @@ has _static_debug_message => ( is => 'rw', isa => ArrayRef[Str] );
 before prepare_action => sub {
     my $c = shift;
     my $path = $c->req->path;
-    my $config = $c->config->{static};
+    my $config = $c->config->{'Plugin::Static::Simple'};
 
     $path =~ s/%([0-9A-Fa-f]{2})/chr(hex($1))/eg;
 
@@ -67,7 +68,7 @@ around dispatch => sub {
     return if ( $c->res->status != 200 );
 
     if ( $c->_static_file ) {
-        if ( $c->config->{static}{no_logs} && $c->log->can('abort') ) {
+        if ( $c->config->{'Plugin::Static::Simple'}->{no_logs} && $c->log->can('abort') ) {
            $c->log->abort( 1 );
         }
         return $c->_serve_static;
@@ -81,7 +82,7 @@ before finalize => sub {
     my $c = shift;
 
     # display all log messages
-    if ( $c->config->{static}{debug} && scalar @{$c->_debug_msg} ) {
+    if ( $c->config->{'Plugin::Static::Simple'}->{debug} && scalar @{$c->_debug_msg} ) {
         $c->log->debug( 'Static::Simple: ' . join q{ }, @{$c->_debug_msg} );
     }
 };
@@ -89,7 +90,15 @@ before finalize => sub {
 before setup_finalize => sub {
     my $c = shift;
 
-    my $config = $c->config->{static} ||= {};
+    $c->log->warn("Deprecated 'static' config key used, please use the key 'Plugin::Static::Simple' instead")
+        if exists $c->config->{static};
+    my $config
+        = $c->config->{'Plugin::Static::Simple'}
+        = $c->config->{'static'}
+        = Catalyst::Utils::merge_hashes(
+            $c->config->{'Plugin::Static::Simple'} || {},
+            $c->config->{static} || {}
+        );
 
     $config->{dirs} ||= [];
     $config->{include_path} ||= [ $c->config->{root} ];
@@ -103,9 +112,6 @@ before setup_finalize => sub {
     # load up a MIME::Types object, only loading types with
     # at least 1 file extension
     $config->{mime_types_obj} = MIME::Types->new( only_complete => 1 );
-
-    # preload the type index hash so it's not built on the first request
-    $config->{mime_types_obj}->create_type_index;
 };
 
 # Search through all included directories for the static file
@@ -117,7 +123,7 @@ sub _locate_static_file {
         File::Spec->no_upwards( File::Spec->splitdir( $path ) )
     );
 
-    my $config = $c->config->{static};
+    my $config = $c->config->{'Plugin::Static::Simple'};
     my @ipaths = @{ $config->{include_path} };
     my $dpaths;
     my $count = 64; # maximum number of directories to search
@@ -172,6 +178,7 @@ sub _locate_static_file {
 
 sub _serve_static {
     my $c = shift;
+    my $config = $c->config->{'Plugin::Static::Simple'};
 
     my $full_path = shift || $c->_static_file;
     my $type      = $c->_ext_to_type( $full_path );
@@ -180,6 +187,12 @@ sub _serve_static {
     $c->res->headers->content_type( $type );
     $c->res->headers->content_length( $stat->size );
     $c->res->headers->last_modified( $stat->mtime );
+    # Tell Firefox & friends its OK to cache, even over SSL:
+    $c->res->headers->header('Cache-control' => 'public');
+    # Optionally, set a fixed expiry time:
+    if ($config->{expires}) {
+        $c->res->headers->expires(time() + $config->{expires});
+    }
 
     my $fh = IO::File->new( $full_path, 'r' );
     if ( defined $fh ) {
@@ -197,7 +210,7 @@ sub _serve_static {
 sub serve_static_file {
     my ( $c, $full_path ) = @_;
 
-    my $config = $c->config->{static} ||= {};
+    my $config = $c->config->{'Plugin::Static::Simple'};
 
     if ( -e $full_path ) {
         $c->_debug_msg( "Serving static file: $full_path" )
@@ -218,7 +231,7 @@ sub serve_static_file {
 sub _ext_to_type {
     my ( $c, $full_path ) = @_;
 
-    my $config = $c->config->{static};
+    my $config = $c->config->{'Plugin::Static::Simple'};
 
     if ( $full_path =~ /.*\.(\S{1,})$/xms ) {
         my $ext = $1;
@@ -307,7 +320,7 @@ the operation by adding various configuration options. In a production
 environment, you will probably want to use your webserver to deliver
 static content; for an example see L<USING WITH APACHE>, below.
 
-=head1 DEFAULT BEHAVIOR
+=head1 DEFAULT BEHAVIOUR
 
 By default, Static::Simple will deliver all files having extensions
 (that is, bits of text following a period (C<.>)), I<except> files
@@ -329,7 +342,7 @@ Logging of static files is turned off by default.
 =head1 ADVANCED CONFIGURATION
 
 Configuration is completely optional and is specified within
-C<MyApp-E<gt>config-E<gt>{static}>.  If you use any of these options,
+C<MyApp-E<gt>config-E<gt>{Plugin::Static::Simple}>.  If you use any of these options,
 this module will probably feel less "simple" to you!
 
 =head2 Enabling request logging
@@ -338,7 +351,7 @@ Since Catalyst 5.50, logging of static requests is turned off by
 default; static requests tend to clutter the log output and rarely
 reveal anything useful. However, if you want to enable logging of static
 requests, you can do so by setting
-C<MyApp-E<gt>config-E<gt>{static}-E<gt>{logging}> to 1.
+C<MyApp-E<gt>config-E<gt>{Plugin::Static::Simple}-E<gt>{logging}> to 1.
 
 =head2 Forcing directories into static mode
 
@@ -347,7 +360,7 @@ that should always be served in static mode.  Regular expressions may be
 specified using C<qr//>.
 
     MyApp->config(
-        static => {
+        'Plugin::Static::Simple' => {
             dirs => [
                 'static',
                 qr/^(images|css)/,
@@ -364,7 +377,7 @@ added to the search path when you specify an C<include_path>. You should
 use C<MyApp-E<gt>config-E<gt>{root}> to add it.
 
     MyApp->config(
-        static => {
+        'Plugin::Static::Simple' => {
             include_path => [
                 '/path/to/overlay',
                 \&incpath_generator,
@@ -408,7 +421,7 @@ If you wish to define your own extensions to ignore, use the
 C<ignore_extensions> option:
 
     MyApp->config(
-        static => {
+        'Plugin::Static::Simple' => {
             ignore_extensions => [ qw/html asp php/ ],
         },
     );
@@ -421,7 +434,7 @@ directory paths to ignore.  If using C<include_path>, the path will be
 checked against every included path.
 
     MyApp->config(
-        static => {
+        'Plugin::Static::Simple' => {
             ignore_dirs => [ qw/tmpl css/ ],
         },
     );
@@ -442,7 +455,7 @@ To override or add to the default MIME types set by the L<MIME::Types>
 module, you may enter your own extension to MIME type mapping.
 
     MyApp->config(
-        static => {
+        'Plugin::Static::Simple' => {
             mime_types => {
                 jpg => 'image/jpg',
                 png => 'image/png',
@@ -450,6 +463,23 @@ module, you may enter your own extension to MIME type mapping.
         },
     );
 
+=head2 Controlling caching with Expires header
+
+The files served by Static::Simple will have a Last-Modified header set,
+which allows some browsers to cache them for a while. However if you want
+to explicitly set an Expires header, such as to allow proxies to cache your
+static content, then you can do so by setting the "expires" config option.
+
+The value indicates the number of seconds after access time to allow caching.
+So a value of zero really means "don't cache at all", and any higher values
+will keep the file around for that long.
+
+    MyApp->config(
+        'Plugin::Static::Simple' => {
+            expires => 3600, # Caching allowed for one hour.
+        },
+    );
+
 =head2 Compatibility with other plugins
 
 Since version 0.12, Static::Simple plays nice with other plugins.  It no
@@ -462,7 +492,7 @@ Enable additional debugging information printed in the Catalyst log.  This
 is automatically enabled when running Catalyst in -Debug mode.
 
     MyApp->config(
-        static => {
+        'Plugin::Static::Simple' => {
             debug => 1,
         },
     );
@@ -572,6 +602,8 @@ Justin Wheeler (dnm)
 
 Matt S Trout, <mst@shadowcat.co.uk>
 
+Toby Corkindale, <tjc@wintrmute.net>
+
 =head1 THANKS
 
 The authors of Catalyst::Plugin::Static:
@@ -586,7 +618,7 @@ For the include_path code from Template Toolkit:
 
 =head1 COPYRIGHT
 
-Copyright (c) 2005 - 2009
+Copyright (c) 2005 - 2011
 the Catalyst::Plugin::Static::Simple L</AUTHOR> and L</CONTRIBUTORS>
 as listed above.
 
